# Application Portfolio Assessment
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment#overview)
  * [What Is Application Portfolio Assessment?](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment#what-is-application-portfolio-assessment?)
  * [Why Is Application Portfolio Assessment Relevant?](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment#why-is-application-portfolio-assessment-relevant?)
  * [Before You Start](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment#before-you-start)
  * [Step-by-Step Guide](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment#step-by-step-guide)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment#related-resources)


Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.
